import 'dart:io';

import 'package:first_project/Components/locale/l10n/app_locale.dart';
import 'package:first_project/data/repositories/anime_repository.dart';
import 'package:first_project/presentation/home_page/bloc/bloc.dart';
import 'package:first_project/presentation/home_page/home_page.dart';
import 'package:first_project/presentation/like_bloc/like_bloc.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'presentation/locale_bloc/locale_bloc.dart';
import 'presentation/locale_bloc/locale_state.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocProvider<LocaleBloc>(
      lazy: false,
      create: (context) => LocaleBloc(Locale(Platform.localeName)),
      child: BlocBuilder<LocaleBloc, LocaleState>(
        builder: (context, state) { return MaterialApp(
          title: 'Flutter Demo',
          locale: state.currentLocale,
          localizationsDelegates: AppLocale.localizationsDelegates,
          supportedLocales: AppLocale.supportedLocales,
          debugShowCheckedModeBanner: false,
          theme: ThemeData(
            colorScheme: ColorScheme.fromSeed(seedColor: Colors.deepPurple),
            useMaterial3: true,
          ),
          home: RepositoryProvider<AnimeRepository>(
            lazy: true,
            create: (_) => AnimeRepository(),
            child: BlocProvider<LikeBloc>(
              lazy: false,
              create: (context) => LikeBloc(),
              child: BlocProvider<HomeBloc>(
                lazy: false,
                create: (context) => HomeBloc(context.read<AnimeRepository>()),
                child: const MyHomePage(title: 'Anime Nya >-<'),
              ),
            ),
          ),
        );
        }
      ),
    );
  }
}
